/**
 * A canvas that can display images into which secret messages can be hidden.
 * 
 * @author Keith Schwarz (htiek@cs.stanford.edu)
 */
import acm.graphics.*;
import java.awt.*;

public class SteganographyPictureCanvas extends GCanvas implements SteganographyConstants {
	/* Stored image. */
	private GImage image;
	
	/**
	 * Creates a new, empty picture canvas.
	 */
	public SteganographyPictureCanvas() {
		setPreferredSize(new Dimension(CANVAS_WIDTH, CANVAS_HEIGHT));
	}
	
	/**
	 * Sets the stored image.  If null, no image is displayed.
	 * 
	 * @param image The image to display, or null if nothing should be displayed.
	 */
	public void setImage(GImage newImage) {
		/* Remove any existing images. */
		if (image != null) {
			remove(image);
		}
		
		/* Set the image. */
		image = newImage;
		
		/* Stretch and add it, if it exists. */
		if (image != null) {
			image.setBounds(0, 0, getWidth(), getHeight());
			add(image);
		}
	}
	
	/**
	 * Returns the underlying image.
	 * 
	 * @return The underlying image.
	 */
	public GImage getImage() {
		return image;
	}
}
